:
#
# $Header: oracle.boot.pp,v 6.58 91/06/21 09:55:00 pkonopka Exp $ oracle.boot
#
# oracle.boot
#
# Default answers are shown in square brackets.
#
# Set up ORACLE Install Directory:
#
# USAGE : 
# The user reads the first cpio/tar archive from tape into ORACLE_HOME, 
# this should be install directory and should have .key.load.* file(s) 
# in ORACLE_HOME.
# Once this is done, the run oracle.boot as follows:
# $ cd ORACLE_HOME/install
# $ ./oracle.boot
#                 -- or --
#  If the user is installing from a compact disc, oracle.boot is
#  called by oracd.sh (in this case the user need not read the 
#  install archive because oracd.sh will handle that.)
#  oracd.sh exports the following variables to oracle.boot :
#      ORACLE_HOME, CD_MOUNT, PLATFORM, DEV_TYPE, LETTER_CASE
# 
# oracle.boot reads the $ORACLE_HOME/.key.load* file(s). This file 
# contains the listing of products in that order on tape and also 
# contains the disks blocks the product will occupy.
# It will also check and see if the mounted file system of ORACLE_HOME 
# has enough space left before loading the product from the tape.
#
# NOTE :
# 1) If the following variables are set in the environment, the value set 
#    in the environment will be used by oracle.boot : 
#   DEF_T_REWIND, T_REWIND will be overridden by DEF_T_REWIND.
#   DEF_T_NO_REWIND, T_NO_REWIND will be overridden by DEF_T_NO_REWIND.
#   DEF_T_REWIND_CMD, T_REWIND_CMD will be overridden by DEF_T_REWIND_CMD.
#   DEF_T_FORWARD_CMD, T_FORWARD_CMD will be overridden by DEF_T_FORWARD_CMD.
#
# 2) Users will be able to specify the tape rewind device names (T_REWIND) and 
#    no-rewind device names (T_NO_REWIND) at the prompt but the commands to 
#    rewind the devices should be the same across a given platform. 
#
# 3) Version 6.42 or higher of oracle.boot must only be used when version
#    6.87 or higher of oracle.install is present due to MLO (NLS) changes.
# 
# Please use the SEQ_DYNIX template
#

CHOWN=/etc/chown
MAKE=make

RANLIB=ranlib

ORACLE_LPPROG="/usr/ucb/lpr"
ORACLE_PAGER="/usr/ucb/more"
ORACLE_LPSTAT="/usr/ucb/lpq"
GROUPS_CMD=groups

#The following are Specific to Port
# sun device driver puts an extra EOF mark after writing cpio/tar's
# EOF so we skip the extra EOF. We use T_FORWARD_CMD to 
# accomplish this.


CHMOD="/bin/chmod"
DF='/bin/df'
LS='/bin/ls'
WC='/usr/ucb/wc'
T_REWIND='/dev/rst0'
T_NO_REWIND='/dev/nrst0'

READ_WRITE_UTILITY="tar"
WRITE="tar cvf"
VERIFY="tar tvf"
READ='tar xvf'

# End of Specific to Port


# Begin oracle.boot {
#
#  Display abort message on interrupt.
#
trap 'echo "ORACLE Installation Aborted !!";exit' 1 2 3 15

#
#  Allow verification/trace to be turned on and off.
#
case $ORACLE_TRACE in
   T)    set -x ;;
esac

#
# Determine how to suppress newline with echo command.
#
case ${N}$C in
   "")    if echo "\c" | grep c >/dev/null 2>&1; then
      N='-n'
   else
      C='\c'
   fi ;;
esac

echo "Running ORACLE installation (oracle.boot)..." 
#
# - if oracle.boot is being called by oracd.sh, then the following
#   variables are already set:
#        DEV_TYPE (= disc), ORACLE_HOME, CD_MOUNT, PLATFORM, LETTER_CASE
#

case "$DEV_TYPE" in
   disc)
      break;;
   *)
      DEV_TYPE="tape"
   
      case "$ORACLE_HOME" in
         "") DIR=`pwd`
            case "`basename $DIR`" in
               install)    cd .. ;;
            esac
            ORACLE_HOME=`pwd` ;;
      esac

      HOME_ANS="undef"
      while : ; do
        while [ "$HOME_ANS" = "undef" ]; do
          echo ""
          echo $N "Using $ORACLE_HOME as the ORACLE_HOME. Is this correct ? $C"
          echo $N "[Y]$C"
          read HOME_ANS
          case "$HOME_ANS" in 
             y|Y)  HOME_ANS=yes;;
             "")   HOME_ANS=yes;;
             n|N)  HOME_ANS="no"; break;; 
             q|Q)  echo "Exiting $0, user requested abort." 		
                   sync ; exit 0 ;;
             *)    echo "Please enter Y, N or Q." ; HOME_ANS="undef";;
          esac
        done
        if [ "$HOME_ANS" = "no" ]; then
           echo ""
           echo $N "Please enter another directory: $C"
           echo $N "[$ORACLE_HOME]$C"
           read NEW_ORACLE_HOME
           case "$NEW_ORACLE_HOME" in
              "") ;;
              *) ORACLE_HOME="$NEW_ORACLE_HOME";;
           esac
        fi
        #test if ORACLE_HOME is a dir
        if [ ! -d "$ORACLE_HOME" ]; then
           echo ""
           echo "$ORACLE_HOME is not a valid directory"
           HOME_ANS="no"
           ORACLE_HOME=`pwd`
        else
           break;
        fi
      done
      ;;
esac

cd $ORACLE_HOME

if [ ! -d $ORACLE_HOME/install ] ; then
   echo ""
   echo "No ORACLE install directory found in $ORACLE_HOME. "
   echo "Check the following:"
   echo "      . The install distribution has been loaded and is readable."
   echo "      . oracle.boot is being invoked from the directory in which"
   echo "        ORACLE will be loaded."
   echo "      . The environment variable ORACLE_HOME is either undefined, or"
   echo "        set to the directory in which ORACLE will be loaded."
   echo "Exiting ORACLE boot."
   sync ; exit 1
fi
INSTALL_HOME="$ORACLE_HOME/install"
LOGFILE=${LOGFILE-"$ORACLE_HOME/install/boot.log"}
export LOGFILE
echo ""

SAVE_ANS="undef"
while : ; do
   while [ "$SAVE_ANS" = "undef" ]; do
      echo $N "Save install output? $C"
      DEFLT="Y"; . $INSTALL_HOME/read.sh; SAVE_ANS=$RDVAR
      case "$SAVE_ANS" in
         y|Y)  ;;
         n|N)  SAVE_ANS="no"; LOGFILE=/dev/null ; break ;;
         q|Q)  echo "Exiting $0, user requested abort."       | tee -a $LOGFILE
               sync ; exit 0 ;;
         *)    echo "Please enter Y, N or Q." ; SAVE_ANS="undef";;
      esac
   done
   if [ "$SAVE_ANS" = "no" ] ; then break; fi
    # test if $LOGFILE already exists.  If yes, ask user
    # if it should be overwritten.
   echo "Current log file is $LOGFILE."
   if [ -r "$LOGFILE" ]; then
      echo $N "$LOGFILE already exists. Overwrite?$C"
   else
      echo $N "Is this correct ? $C"
   fi
   DEFLT="Y"; . $INSTALL_HOME/read.sh; ANS=$RDVAR
   echo ""
   case "$ANS" in
      y|Y)  echo "New Log File Created" > $LOGFILE
            break;;
      q|Q)  echo "Exiting $0, user requested abort."          | tee -a $LOGFILE
            sync ; exit 0 ;;
      *)  echo $N "Please enter the name of a new file. $C"
          DEFLT="boot.$$.log"
          . $INSTALL_HOME/read.sh; ANS=$RDVAR
          case "$ANS" in
             "$DEFLT" ) LOGFILE=$DEFLT;;
             /*)        LOGFILE=$RDVAR;;
             *)         LOGFILE=`pwd`/$RDVAR;;
          esac;;
   esac
done
#
date >> $LOGFILE 
echo "ORACLE BOOT DIAGNOSTICS FILE" >> $LOGFILE
echo "" >> $LOGFILE
if [ "$LOGFILE" != "/dev/null" ]; then chmod 666 $LOGFILE; fi


if [ "$DEV_TYPE" = "tape" ]; then
# If the following variables are set in environment, use those :
   case "$DEF_T_REWIND" in
      "") T_REWIND=$T_REWIND;;
      *)  T_REWIND=$DEF_T_REWIND;;
   esac
   echo "Using Rewind Device (T_REWIND) = $T_REWIND"
   echo $N "Is this correct ? $C"
   DEFLT="Y"; . $INSTALL_HOME/read.sh; ANS=$RDVAR
   echo ""
   case "$ANS" in
      y|Y) break;;
      q|Q) echo "Exiting $0, user requested abort." 	
           sync ; exit 0 ;;
      *) echo $N "Please enter the name of a new device file. $C"
         DEFLT="$T_REWIND"
         . $INSTALL_HOME/read.sh; ANS=$RDVAR
         case "$ANS" in
            /*) LOG=$RDVAR ;;
            *)  LOG=`pwd`/$RDVAR ;;
         esac
         T_REWIND=$ANS
         echo "Using updated rewind device (T_REWIND) = $T_REWIND";;
   esac

   case "$DEF_T_NO_REWIND" in
      "") T_NO_REWIND=$T_NO_REWIND;;
      *)  T_NO_REWIND=$DEF_T_NO_REWIND;;
   esac
   echo "Using No-Rewind Device (T_NO_REWIND) = $T_NO_REWIND"
   echo $N "Is this correct ? $C"
   DEFLT="Y"; . $INSTALL_HOME/read.sh; ANS=$RDVAR
   echo ""
   case "$ANS" in
      y|Y) break;;
      q|Q) echo "Exiting $0, user requested abort." 	
           sync ; exit 0 ;;
      *) echo $N "Please enter the name of a new device file. $C"
         DEFLT="$T_NO_REWIND"
         . $INSTALL_HOME/read.sh; ANS=$RDVAR
         case "$ANS" in
            /*) LOG=$RDVAR ;;
            *)  LOG=`pwd`/$RDVAR ;;
         esac
         T_NO_REWIND=$ANS
         echo "Using updated No-Rewind device (T_NO_REWIND) = $T_NO_REWIND";;
   esac

   T_REWIND_CMD="/bin/mt -f $T_REWIND rew"
   T_FORWARD_CMD()
   { for i in 1 2 3 4 5 6 7 8 9 10
     do
        if `/bin/mt -f $T_NO_REWIND fsf >/dev/null 2>&1`; then
           break;
        fi
     done
   }

# If DEF_T_REWIND_CMD is defined, then use that.
   case "$DEF_T_REWIND_CMD" in
      "") ;;
      *)  T_REWIND_CMD=$DEF_T_REWIND_CMD;;
   esac

# If DEF_T_FORWARD_CMD is defined, then use that.
   case "$DEF_T_FORWARD_CMD" in
      "") ;;
      *)  T_FORWARD_CMD=$DEF_T_FORWARD_CMD;;
   esac
fi #  DEV_TYPE = tape

cd $ORACLE_HOME
echo ORACLE_HOME=$ORACLE_HOME

TAPE_COUNT=1

if [ ! -r $ORACLE_HOME/.key.load.$TAPE_COUNT  ]; then
   echo ""
   echo "$ORACLE_HOME/.key.load.$TAPE_COUNT is not readable." | tee -a $LOGFILE
   echo "Make sure that :"                                    | tee -a $LOGFILE
   if [ "$DEV_TYPE" = "tape" ]; then
      echo ". Correct distribution tape is in the tape drive" | tee -a $LOGFILE
      echo ". Rewind the tape device"                         | tee -a $LOGFILE
      echo ". Read the first archive on tape"                 | tee -a $LOGFILE
   else
      echo ". Correct distribution disc is in the player"     | tee -a $LOGFILE
      echo ". Reload the install archive on the disc"         | tee -a $LOGFILE
   fi
   echo ". Rerun $0"                                          | tee -a $LOGFILE
   echo ". $0 Aborted!!"                                  | tee -a $LOGFILE
   exit 1
fi

KEY_FILES=`$LS -l $ORACLE_HOME/.key.load.* | $WC -l | awk '{print $1}' `

CWD=`pwd`
DISK_SPACE=`$DF $CWD | awk 'NR == 2 { print $4 }'`

# We use 2000 disk blocks as an arbitrary number and will allow atleast 
# the warning  message being printed on screen.
if test $DISK_SPACE -le 2000 ; then 
   echo "WARNING: Insufficient space on disk."                | tee -a $LOGFILE
   echo "         Please ensure there is enough disk space."  | tee -a $LOGFILE
   echo "  "                                                  | tee -a $LOGFILE
   $DF $CWD
   echo "  " 
   while : ; do
      echo $N "Abort? $C"
      DEFLT="Y"; . $INSTALL_HOME/read.sh; ABORT=$RDVAR
      case "$ABORT" in
         y|Y) 
             echo "Installation Aborted!!"                | tee -a $LOGFILE
             exit 1;;
         *) 
             break;;
      esac  
   done
fi


echo ""                       
echo "This ORACLE distribution consists of $KEY_FILES $DEV_TYPE(s)." | tee -a $LOGFILE

# Loop until all tapes are proccessed {
while [ $TAPE_COUNT -le $KEY_FILES ]
do
#   first, print out the contents of current tape/disc
   CURR_KEY_FILE="$ORACLE_HOME/.key.load.$TAPE_COUNT"
   echo ""
   if [ "$DEV_TYPE" = "tape" ]; then
      echo "Insert $DEV_TYPE no $TAPE_COUNT, which contains :" | tee -a $LOGFILE
   else
      echo "The /$PLATFORM directory of the disc contains : "  | tee -a $LOGFILE
   fi
   RELEASE_NAME=`cat $CURR_KEY_FILE | awk '{print $4}'`
   case $RELEASE_NAME in
      "")
         echo
         echo "PRODUCT			DISK BLOCKS" | tee -a $LOGFILE
         echo 
      ;;
      *)
         echo
         echo "PRODUCT			DISK BLOCKS		RELEASE" | tee -a $LOGFILE
         echo 
      ;;
   esac
   for ITEM1 in `cat $CURR_KEY_FILE | awk '{print $1}'`
   do
      ITEM2=`grep "$ITEM1	" $CURR_KEY_FILE | awk '{print $2}'`
      ITEM3=`grep "$ITEM1	" $CURR_KEY_FILE | awk '{print $3}'`
      ITEM4=`grep "$ITEM1	" $CURR_KEY_FILE | awk '{print $4}'`
      NAME_LENGTH=`echo $ITEM3 | $WC -c | awk '{print $1}' `
      #echo XX NAME_LENGTH=$NAME_LENGTH
      if [ "$NAME_LENGTH" -gt 8 ]; then
          echo "$ITEM3		$ITEM2			$ITEM4"| tee -a $LOGFILE
      else
          echo "$ITEM3			$ITEM2			$ITEM4"| tee -a $LOGFILE
      fi
   done
   echo
   echo $N "Press RETURN when ready : $C"
   read RETURN
   case "$RETURN" in 
      "")   ;;
      q|Q)  echo "Exiting $0, user requested abort."          | tee -a $LOGFILE
            sync ; exit 0 ;;
   esac

   if [ "$DEV_TYPE" = "tape" ]; then
#    check that the tape`s set up properly
      EXIT_STATUS=1
      while true
      do
         $ORACLE_HOME/bin/opendev $T_REWIND
         EXIT_STATUS=$?
         if [ $EXIT_STATUS = 0 ]
         then
            break
         else
            echo "$DEV_TYPE error, please make sure :"        | tee -a $LOGFILE
            echo "  . $DEV_TYPE is inserted properly "        | tee -a $LOGFILE
            echo "  . correct device name is being used"      | tee -a $LOGFILE
            echo ""
            echo $N "Insert $DEV_TYPE and Press RETURN: $C"
            read RETURN
            case "$RETURN" in 
               "")  ;;
               q|Q) echo "Exiting $0, user requested abort."  | tee -a $LOGFILE
                    sync ; exit 0 ;;
            esac
         fi
      done
      echo ""
      echo 'Rewinding the tape to the beginning....'          | tee -a $LOGFILE
      $T_REWIND_CMD
   fi #  end DEV_TYPE = tape
    
   if [ ! -r $CURR_KEY_FILE  ]
   then 
      echo "$CURR_KEY_FILE is not readable."                    | tee -a $LOGFILE
      echo "$0 Aborted !!"                                    | tee -a $LOGFILE
      exit 2
   fi
#       Now, we are ready to read the products from tape/disc to disk
   KEY_LENGTH=`cat $CURR_KEY_FILE | $WC -l | awk '{print $1}' `
   if [ $KEY_LENGTH -gt 0 ]
   then
      if [ "$DEV_TYPE" = "tape" ]; then
         echo "The tape has $KEY_LENGTH $READ_WRITE_UTILITY archives." | tee -a $LOGFILE
      else
         echo "The /$PLATFORM directory of the disc has $KEY_LENGTH $READ_WRITE_UTILITY archives." | tee -a $LOGFILE
      fi
   else
      echo "WARNING : $CURR_KEY_FILE file is empty."          | tee -a $LOGFILE
      echo "          There is nothing to load."              | tee -a $LOGFILE
      exit 1
   fi
   PRODUCT_COUNT=0 


# for each run through the following for loop, there will be one of
# four actions taken: quit the script, skip the current product, 
# load (read) the current product, or exit the loop. the code for the
# latter three choices is carried out after the for loop.
#  {
   for PRODX in `cat $CURR_KEY_FILE | awk '{print $1}'`
   do
      PRODUCT_COUNT=`expr $PRODUCT_COUNT + 1`
      MKTG_NAME=`grep "$PRODX	" $CURR_KEY_FILE | awk '{print $3}'`
      case $PRODX in
         ./install | install)
#           If the product is install, skip it,
            echo "$MKTG_NAME has already been loaded;"        | tee -a $LOGFILE
            ACTION="skip"
            if [ $KEY_LENGTH -eq 1 ]
            then 
               echo "NOTE: There is only 1 file listed in $CURR_KEY_FILE" | tee -a $LOGFILE
            fi 
            ;;
         *) 
            DIR_SIZE=`grep "$PRODX	" $CURR_KEY_FILE | awk '{print $2}'`

            DISK_SPACE=`$DF $CWD | awk 'NR == 2 { print $4 }'`

            DIFFERENCE=`expr $DISK_SPACE - $DIR_SIZE`
            if test $DIFFERENCE -le 0 ;  then
               echo "There is not enough disk space to read in $MKTG_NAME." | tee -a $LOGFILE
               echo ""
               while : ; do
                  echo $N "Go on to the next product (N) or quit (Q)? $C"
                  DEFLT="N"; . $INSTALL_HOME/read.sh; ABORT=$RDVAR
                  case "$ABORT" in
                     q|Q)
                        echo "Installation Aborted!!"     | tee -a $LOGFILE
                        exit 1;;
                     n|N)
                        if [ $PRODUCT_COUNT -lt $KEY_LENGTH ] 
                        then
                           ACTION="skip"
                        else
                           ACTION="exit"
                           echo $N "$MKTG_NAME was the $C"    | tee -a $LOGFILE
                           echo "last product on $DEV_TYPE."  | tee -a $LOGFILE
                        fi
                        break;;
                     *)
                        echo "Please enter N or Q";;
                  esac
               done
            else
               while : ; do
                  echo $N "Read $MKTG_NAME in (Y), go on to $C"
                  echo $N "the next product (N), or quit (Q)? $C"
                  DEFLT="Y"; . $INSTALL_HOME/read.sh; CONTINUE=$RDVAR
                  case "$CONTINUE" in
                     q|Q)
                        echo "Installation Aborted!!"     | tee -a $LOGFILE
                        exit 1;;
                     n|N)
                        if [ $PRODUCT_COUNT -lt $KEY_LENGTH ]
                        then
                           ACTION="skip"
                        else
                           ACTION="exit"
                           echo $N "$MKTG_NAME was the $C"    | tee -a $LOGFILE
                           echo "last product on $DEV_TYPE."  | tee -a $LOGFILE
                        fi
                        break;;
                     y|Y)
                        PRODD=`echo $PRODX | tr "[a-z]" "[A-Z]"`
                        PRODL=`echo $PRODX | tr -d '/'`
#                       check to see if the directory already
#                       exists, & if does, give error message
#                       & then make that directory writeable
                        if [ -d $PRODX ]
                        then
                           while : ; do
                             echo "WARNING: $MKTG_NAME already exists."                    | tee -a $LOGFILE
                             echo "Continuing will overwrite the existing $MKTG_NAME."     | tee -a $LOGFILE
                             echo $N "     Continue (Y), go on to the next product (N), or quit (Q)? $C"
                             DEFLT="N"; . $INSTALL_HOME/read.sh; T_INSTALL=$RDVAR
                             case "$T_INSTALL" in
                                y|Y)
                                   # set up for the read ...
                                   echo "$CHMOD u+w `cat $PRODX/install/$PRODD.DIST`" >> $LOGFILE
                                   $CHMOD u+w `cat $PRODX/install/$PRODD.DIST` 2>> $LOGFILE
                                   rm -rf $PRODX/install/runtime/* 2>> $LOGFILE
                                   ACTION="read"
                                   break;;
                                n|N)
                                   if [ $PRODUCT_COUNT -lt $KEY_LENGTH ]
                                   then
                                      ACTION="skip"
                                   else
                                      ACTION="exit"
                                      echo "$MKTG_NAME was the last product on $DEV_TYPE." | tee -a $LOGFILE
                                   fi
                                   break;;
                                q|Q)
                                   echo "User Requested Abort."                            | tee -a $LOGFILE
                                   sync; exit 0;;
                                *)
                                   echo "Please enter Y, N or Q.";;
                             esac
                           done
                        else
#                          set up for the read ...
                           $CHMOD u+r ./bin/*
                           $CHMOD u+w ./bin/*
                           ACTION="read"
                        fi # if [ -d PRODX ] ...
                        break;;
                     *)
                        echo "Please enter Y, N or Q";;
                  esac
               done
            fi
      esac

# ============ SKIP =============================================

      if [ "$ACTION" = "skip" ]; then
         echo "Skipping $MKTG_NAME ...."                      | tee -a $LOGFILE
         if [ "$DEV_TYPE" = "tape" ]; then
            $VERIFY $T_NO_REWIND > /dev/null 2>> $LOGFILE
            if [ -n "$DEF_T_REWIND_CMD" ]; then
               $T_FORWARD_CMD
            else
               T_FORWARD_CMD
            fi
         fi

         case $PRODX in 
          ./install | install)
            
# ask user about the NLS license. if user is not licensed for NLS,
# remove all product message files except for the US ones.
            LANG=
            echo ""
            while : ; do
               echo $N "Are you licensed to use the Multilingual Option? $C"
               DEFLT="Y"; . $INSTALL_HOME/read.sh; ANS=$RDVAR
               case "$ANS" in
                  y|Y)  break;;
                  n|N)  while : ; do
                  echo $N "Please indicate the native language to be installed:

     1. English
     2. Danish
     3. Dutch
     4. Finnish
     5. French
     6. German
     7. Italian
     8. Norwegian
     9. Spanish
    10. Swedish

Enter the number of the language: $C"
                         DEFLT="1"; . $INSTALL_HOME/read.sh; ANS=$RDVAR
                         case $ANS in
                            1) LANG=us  ; break;;
                            2) LANG=dk  ; break;;
                            3) LANG=nl  ; break;;
                            4) LANG=sf  ; break;;
                            5) LANG=f   ; break;;
                            6) LANG=d   ; break;;
                            7) LANG=i   ; break;;
                            8) LANG=n   ; break;;
                            9) LANG=e   ; break;;
                           10) LANG=s   ; break;;
                            *) echo "Enter 1...10, please.";;
                         esac
                        done
                        break;;
                  q|Q)  echo "User requested abort."; sync; exit 0;;
                  *)    echo "Enter Y, N or Q, please.";;
               esac
            done
            ;;
         esac

      fi #  ACTION = skip

# ==============================================================

# ============ READ ============================================

      if [ "$ACTION" = "read" ]; then
         echo "Reading $MKTG_NAME ...."                       | tee -a $LOGFILE
         if [ "$DEV_TYPE" = "tape" ]; then
            echo "$READ $T_NO_REWIND"
            $READ $T_NO_REWIND 2>&1                           | tee -a $LOGFILE
            if [ -n "$DEF_T_REWIND_CMD" ]; then
               $T_FORWARD_CMD
            else
               T_FORWARD_CMD
            fi
         else
#         create the name of the disc archive from PRODX
            CD_PROD="`echo $PRODX | awk '{print substr($1,3,8)}'`.dat"

            if [ "$LETTER_CASE" = "upper" ]; then
#           convert CD_PROD to uppercase
               CD_PROD=`echo $CD_PROD | tr "[a-z]" "[A-Z]"`
            fi

#          untar from disc
            echo "$READ $CD_MOUNT/$PLATFORM/$CD_PROD"
            $READ $CD_MOUNT/$PLATFORM/$CD_PROD*
         fi

        case $VERIFY_MEDIA in
            TRUE) 
	          # $ORACLE_HOME/install/bt_comp_rel.sh $PRODX
	          echo $SRCHOME/install-/bt_comp_rel.sh $PRODX
	          $SRCHOME/install-/bt_comp_rel.sh $PRODX
                  EXIT_STATUS=$?
                  case $EXIT_STATUS in
                      0) break
                      ;;
                      *) echo "ERROR : bt_comp_rel.sh Exited with code $EXIT_STATUS" | tee -a $LOGFILE
                      ;;
                  esac
            ;;
            *)
            ;;
        esac

#  now we remove the appropriate NLS files

         echo "MKTG_NAME=$MKTG_NAME" >> $LOGFILE  
         echo "PRODX=$PRODX" >> $LOGFILE  
         echo "LANG=$LANG"  >> $LOGFILE  
         case $LANG in
            "")
               ;;
            *)
               echo "Removing NLS files from $MKTG_NAME" >> $LOGFILE
               echo "             except language $LANG" >> $LOGFILE
               for file in `find $ORACLE_HOME/$PRODX/mesg -name \
                                "*.ms*" -print 2> /dev/null \
                 | egrep -v "(.*/mesg/.*us\.ms[bg]|.*/mesg/.*\$LANG\.ms[bg])" \
                 | tr "\012" " "`
               do
                  echo rm -f $file >> $LOGFILE
                  rm -f $file     2>> $LOGFILE
               done
               ;;
         esac
         $CHMOD u-w ./bin/*
      fi #  ACTION = read

# ================================================(end READ)=====

# ========== EXIT ===============================================

      if [ "$ACTION" = "exit" ]; then break; fi

# ===============================================================

   done # } while : ; do PRODX

# clean up  

   if [ "$DEV_TYPE" = "tape" ]; then
      echo "Tape no $TAPE_COUNT is finished: "                | tee -a $LOGFILE
      echo 'Rewinding the tape to the beginning....'          | tee -a $LOGFILE
      $T_REWIND_CMD
   fi

   TAPE_COUNT=`expr $TAPE_COUNT + 1`

done # } while [ $TAPE_COUNT -le $KEY_FILES ] ...


echo "    
ORACLE BOOT install completed.

To complete the installation, we recommend that you now follow these steps:

    1. Login as root.
    2. Run the \"oracle.install\" script.
" | tee -a $LOGFILE

rm -rf $ORACLE_HOME/.key.load.*

sync;sync;sync
exit 0

# End oracle.boot }
