:
# 
# $Header: prtversion.sh,v 6.15 91/01/24 16:06:57 mguzman Exp $ prtversion.sh 
# 
# prtversion.sh
#
# usage: prtversion.sh [-f filename] [-p pathname]
#
# prints the version number of the oracle utilities
# prints the revision number from rcs header if it is a sh/csh script
# prints error output when error is encountered
#
# option: -f prints the version numbers to the specified file instead of stdout
#	  -p allows user to specify pathname of the bin directory instead of
#	     $ORACLE_HOME/bin
#

# parse options and test for command error
for i in "$@"
do
  case $1 in
  "-f") shift;
        case $1 in
        "")  echo "$0: missing filename";
             exit 1;;
        *)   FILENAME=$1;
             TRASH="/dev/null";;
        esac
        shift;;
  "-p") shift;
        case $1 in
        "")  echo "$0: missing pathname";
             exit 1;;
        *)   BINHOME=$1;;
        esac
        shift;;
    -*) echo "$0: bad option";
        exit 1;;
    "") break ;;
     *) echo "$0: bad argument";
        exit 1;;
  esac
done

# set up abbreviations; modify or add xxxGROUPxxx for new utilities
BINHOME=${BINHOME-$ORACLE_HOME/bin}
FILENAME=${FILENAME-"/dev/tty"}
TMP=tmp$$
TMPFILE=TMP$$
TRASH=${TRASH-"/dev/tty"}

# MISc utilities with -? option
MISGROUP="crt exp imp odl oramail orasrv rpt rpf \
	 sqldba sqlload odl2ldr sqlplus loader2 sqlcalc"

# OTHer utilities without -? option, runform30 is being used to obtain
# plsql and orakit versions
OTHGROUP="pcc"

# FORms, runform30 is being used to obtain plsql and orakit versions
FORGROUP="convert iac generate iag runform iap \
	  convert30 iac30 generate30 iag30 runform30 iap30"

# MENu
MENGROUP="dmd dmm dmu sqlmenu \
	  docmenu50 genmenu50 runmenu50 sqlmenu50"

# Sql*ReportWriter
SRWGROUP="dumprep genrep loadrep moverep printdef runrep sqlrep"

# CASe
CASGROUP="casedict casegen casedes"

# QMX
QMXGROUP="sqlqmx getkey"

# remove temp files when interrupted
trap "rm -f $TMP;if [ -f $TMPFILE ];then sort $TMPFILE > $FILENAME;fi;rm -f $TMPFILE; exit 1" 1 2 3 15

if echo "\c"|grep "c" >/dev/null 2>&1
then
  NFLAG="-n"
  CARFLG=""
else
  NFLAG=""
  CARFLG="\c"
fi

echo $NFLAG "Looking for Version numbers..$CARFLG" > $TRASH
echo $NFLAG ".$CARFLG" > $TRASH
echo > $TRASH

echo >> $TMPFILE
echo "Miscellaneous utilities with -\? option:" >> $TMPFILE
for FILE in $MISGROUP
do
  if [ -f "$BINHOME/$FILE" ]
  then
    $BINHOME/$FILE -\? < /dev/null > $TMP 2>&1
    VERS=`grep "Version" $TMP|sed 's/.* Version //
				s/ on.*$//'`
    echo "	$FILE			$VERS" >> $TMPFILE
  fi
done
rm -f $TMP

echo >> $TMPFILE
echo "Miscellaneous utilities without -\? option:" >> $TMPFILE
for FILE in $OTHGROUP
do
  if [ -f "$BINHOME/$FILE" ]
  then
    $BINHOME/$FILE < /dev/null > $TMP 2>&1
    VERS=`grep "Version" $TMP|sed 's/.* Version //
				s/ on.*$//
				2,\$d'`
    echo "	$FILE			$VERS" >> $TMPFILE
  fi
done
rm -f $TMP

echo >> $TMPFILE
echo "Forms utilities:" >> $TMPFILE
if [ -f "$BINHOME/runform30" ]
then
    $BINHOME/runform30 < /dev/null > $TMP 2>&1
    VERS=`grep "Toolkit" $TMP|sed 's/.* Version //
				2,\$d'`
    echo "	orakit          	$VERS" >> $TMPFILE
    VERS=`grep "PL/SQL" $TMP|sed 's/.* Version //
				2,\$d'`
    echo "	plsql                	$VERS" >> $TMPFILE
    rm -f $TMP
fi

for FILE in $FORGROUP
do
  if [ -f "$BINHOME/$FILE" ]
  then
    $BINHOME/$FILE \? < /dev/null > $TMP 2>&1
    VERS=`grep "Version" $TMP|sed 's/.* Version //
				s/ on.*$//
				2,\$d'`
    echo "	$FILE			$VERS" >> $TMPFILE
  fi
done
rm -f $TMP

echo >> $TMPFILE
echo "Menu utilities:" >> $TMPFILE
for FILE in $MENGROUP
do
  if [ -f "$BINHOME/$FILE" ]
  then
    $BINHOME/$FILE -\? < /dev/null > $TMP 2>&1
    VERS=`grep "Version" $TMP|sed 's/.* Version //
				s/ on.*$//
				2,\$d'`
    echo "	$FILE			$VERS" >> $TMPFILE
  fi
done
rm -f $TMP

echo >> $TMPFILE
echo "Sql*ReportWriter utilities:" >> $TMPFILE
for FILE in $SRWGROUP
do
  if [ -f "$BINHOME/$FILE" ]
  then
    $BINHOME/$FILE -\? < /dev/null > $TMP 2>&1
    VERS=`grep "Version" $TMP|sed 's/.* Version //
				s/ on.*$//
				2,\$d'`
    echo "	$FILE			$VERS" >> $TMPFILE
  fi
done
rm -f $TMP

echo >> $TMPFILE
echo "Case utilities with -\? option:" >> $TMPFILE
for FILE in $CASGROUP
do
  if [ -f "$BINHOME/$FILE" ]
  then
    $BINHOME/$FILE -\? < /dev/null > $TMP 2>&1
    case $FILE in
        "casedes") DESVERS=`grep "Version" $TMP|sed 's/.*Designer  //
				s/ for.*$//'`;
		   DESLEVEL=`strings $BINHOME/casefront | grep Version | grep "CASE :" |sed 's/.* -/-/'`;
		   VERS="$DESVERS $DESLEVEL";;
        *) VERS=`grep "Version" $TMP|sed 's/.* Version //
				s/ on.*$//
				2,\$d'`
    esac
    echo "	$FILE			$VERS" >> $TMPFILE;
  fi
done
rm -f $TMP

echo >> $TMPFILE
echo "SQL*QMX utilities:" >> $TMPFILE
for FILE in $QMXGROUP
do
  if [ -f "$BINHOME/$FILE" ]
  then
    $BINHOME/$FILE -\? < /dev/null > $TMP 2>&1
    VERS=`grep "Version" $TMP|sed 's/.* Version //
				s/ on.*$//
				2,\$d'`
    echo "	$FILE			$VERS" >> $TMPFILE
  fi
done
rm -f $TMP

echo >> $TMPFILE
echo "Easy*SQL:" >> $TMPFILE
if [ -f "$BINHOME/easysql" ]
then
    $BINHOME/easysql -\? < /dev/null > $TMP 2>&1
    VERS=`grep "Easy\*SQL" $TMP|sed 's/.* Version //
				s/ on.*$//
				2,\$d'`
    echo "	easysql 		$VERS" >> $TMPFILE
    VERS=`grep "Charting Library" $TMP|sed 's/.* Version //
				2,\$d'`
    if [ "$VERS" != "" ]
    then
    echo "	charting library       	$VERS" >> $TMPFILE
    fi
    rm -f $TMP
fi


echo "Done" > $TRASH
# echo $NFLAG "Sorting......$CARFLG" > $TRASH
# sort $TMPFILE > $TMP
# echo "Done" > $TRASH

# print header
echo > $FILENAME
echo "	Utility                   Version" >> $FILENAME
echo "	-------                   -------" >> $FILENAME
cat $TMPFILE >> $FILENAME

# remove temp files
rm -f $TMP $TMPFILE

echo > $TRASH
echo "Complete." > $TRASH
