:
# 
# $Header: read.sh,v 6.6 90/10/30 14:38:47 tpopovic Exp $ read.sh
# 

# Read an input or use a default value with optional escape to sh.
#       usage:    DEFLT=<default> ; . read.sh ; SH_VAR=$RDVAR
#  Use a ! to escape to a sub-shell. When you exit from the
#  sub-shell you may still enter a new value or use the displayed
#  default.  If the variable ORACLE_DEFAULT is set to T, then don't
#  do a read, but just take the DEFLT value.
#
#
#  This utility also has support to force a "read" from the terminal (as
#  opposed to the default of stdin)...  This is done by setting the shell
#  variable `FORCE_READ_FROM_TTY' before issuing the command.
#


case $ORACLE_DEFAULT in
    T)	RDVAR=$DEFLT ; echo "$DEFLT" ;;
    *)	while :
	do
	    echo $N "[${DEFLT}]: $C"
	    #
	    # The following will test whether or not ITD is running.
	    # (If ITDDRV==T|Y, we are running with the ITD test driver.)
	    # If it is, we will cache the proper sync character in var ITDSYNC
	    # which will get loaded from the `$ITDfl' file.  Note that we will
	    # only read in the file if needed, thus its typically loaded *only*
	    # during our first test msg (for reasons of efficiency)...
	    # (An error msg is displayed if the sync file is not found.)
	    #
	    case "$ITDDRV" in
	    T|Y) echo ${ITDSYNC=`ITDfl=$ORACLE_HOME/install/itdsync.ch
if [ -f $ITDfl ];then cat $ITDfl;else echo "$ITDfl isnt set" >&2; exit 1; fi`}
	    esac


	    # This is what I would have like to use:
	    #   RDVAR="`line ${FORCE_READ_FROM_TTY+</dev/tty}`"
	    # however, it caused some problems...therefore,
	    # we use the equivalent IF ... ELSE ... FI construct
	    # (or case for efficiency reasons).
	    #
	    # Some details:  The shell will not allow any internal shell
	    # builtin-cmd to have redirection of input (with the exception
	    # of looping constructs); therefore, to get arround this we 
	    # will jump into a sub-shell and redirect input via the exec
	    # call and grab the input from the terminal.
	    #
	    # The reason for the sub-shell is not to disturb the current
	    # input source.  (We may want to normally read from some file
	    # and occasionally force reads from the tty device...)

	    case "${FORCE_READ_FROM_TTY}" in
	     "")			# read from std-in
		read RDVAR ;;
	     *)				# force the read from /dev/tty
		RDVAR="`(
			exec </dev/tty;
			read t ;echo $t;
			)`"
		;;
	    esac

	    case $RDVAR in
		"")	RDVAR=$DEFLT ; break ;;
		!*)	${SHELL-/bin/sh} ; echo ;;
		*)	break ;;
	    esac
	done ;;
esac
